<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>CircleTPR</name>
    <message>
        <location filename="../CircleTPR.js" line="+39"/>
        <source>Point on circle</source>
        <translation>Punkt na okręgu</translation>
    </message>
    <message>
        <location filename="../CircleTPRInit.js" line="+2"/>
        <source>&amp;Tangent, Point, Radius</source>
        <translation>S&amp;tyczny, punkt, promień</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Draw circle tangential to entity, through point with radius</source>
        <translation>Rysuje okrąg styczny do elementu, przez punkt. o danym promieniu</translation>
    </message>
    <message>
        <location filename="../CircleTPR.ui" line="+17"/>
        <source>Radius:</source>
        <translation>Promień:</translation>
    </message>
</context>
</TS>
